@@ -3,6 +3,7 @@
 #' @inheritParams D4TAlink-common-args
 #' @inheritParams readBinary
 #' @return Object of class \code{\link{D4TAlinkTask}} or NULL if the \code{task} does not exists.
+#' @importFrom rjson fromJSON
 #' @export
 loadTask <- function(project, package, taskname,
                      sponsor=getTaskSponsor(),
@@ -13,7 +14,7 @@ loadTask <- function(project, package, taskname,
   if(is.null(ta)) {
     fn <- file.path(binaryDir(tabk),paste0(tabk$task,"_task.json"))
     if(file.exists(fn)) {
-      v <- jsonlite::read_json(fn)
+      v <- rjson::fromJSON(file=fn)
       ta <- tabk
       for(n in names(v)) ta[[n]] <- unlist(v[[n]])
     }
