@@ -52,6 +52,7 @@ archiveTask <- function(task,file,overwrite=FALSE,...) {
 #' @inheritParams utils::unzip
 #' @inheritDotParams utils::unzip
 #' @importFrom utils unzip
+#' @importFrom rjson toJSON
 #' @return if list FALSE, the task imported incisibly, otherwise the list of files in the archive.
 #' @export
 restoreTask <- function(file,overwrite=FALSE,list=FALSE,code=TRUE,...) {
@@ -85,7 +86,7 @@ restoreTask <- function(file,overwrite=FALSE,list=FALSE,code=TRUE,...) {
   }
   ## ======
   saveBinary(task,task,"task")
-  cat(jsonlite::toJSON(unclass(task)),file=file.path(binaryDir(task),paste0(task$task,"_task.json")))
+  cat(rjson::toJSON(unclass(task)),file=file.path(binaryDir(task),paste0(task$task,"_task.json")))
   ## ======
   if(list) invisible(ls)
   invisible(task)
