@@ -19,6 +19,7 @@ initTaskRmd <- function(task,encoding="unknown",overwrite=FALSE,suffix=NA) {
   fn <- rmdFn(task,suffix=suffix)
   if(file.exists(fn)&&!overwrite) stop("The task R markdown file already exists. Set 'overwrite' to FALSE to overwrite the existing file.")
   fo <- function(x) { for(e in c("%","_")) x<-gsub(e,paste0("\\",e),x,fixed=TRUE) ; x }
+  fo <- function(x) x
   tfn <- getTaskRmdTemplate()
   tin <- readLines(tfn,encoding=encoding,warn=FALSE)
   tin <- gsub("%DATE%"    ,task$date,tin,fixed=TRUE)
@@ -97,13 +98,16 @@ formatTaskDocx <- function(task,ifn) {
         s <- gsub(paste0("%",toupper(e),"%"),task[[e]],s,fixed=TRUE)
       }
     }
-    if(grepl('%TYPE%',s,fixed=TRUE)) {
-      sa <- TRUE
-      s <- gsub('%TYPE%','task report',s,fixed=TRUE)
-    }
-    if(grepl('%ROOT%',s,fixed=TRUE)) {
-      sa <- TRUE
-      s <- gsub('%ROOT%',getTaskRoot(),s,fixed=TRUE)
+    re <- list(
+      `%YEAR%`=format(as.POSIXct(task$date),"%Y"),
+      `%TYPE%`='task report',
+      `%ROOT%`=getTaskRoot()
+    )
+    for(n in names(re)) {
+      if(grepl(n,s,fixed=TRUE)) {
+        sa <- TRUE
+        s <- gsub(n,re[[n]],s,fixed=TRUE)
+      }
     }
     if(sa) {
       if(options()$verbose) cat("*")
